==> haskell-cmdargs-0.10.17-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cmdargs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmdargs
version: 0.10.17
id: cmdargs-0.10.17-gTr0lzwrHbBcQQ47pfTGo
key: cmdargs-0.10.17-gTr0lzwrHbBcQQ47pfTGo
license: BSD3
copyright: Neil Mitchell 2009-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/cmdargs#readme
synopsis: Command line argument processing
description:
    This library provides an easy way to define command line parsers. Most users
    will want to use the "System.Console.CmdArgs.Implicit" module, whose
    documentation contains an example.
    .
    * "System.Console.CmdArgs.Explicit" provides a way to write command line
    parsers for both single mode programs (most programs) and multiple
    mode programs (e.g. darcs or cabal). Parsers are defined by constructing
    a data structure.
    .
    * "System.Console.CmdArgs.Implicit" provides a way to concisely define
    command line parsers, up to three times shorter than getopt. These parsers
    are translated into the Explicit data type.
    .
    * "System.Console.CmdArgs.GetOpt" provides a wrapper allowing compatiblity
    with existing getopt parsers, mapping to the Explicit data type.
    .
    For a general reference on what command line flags are commonly used,
    see <http://www.faqs.org/docs/artu/ch10s05.html>.
category: Console
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    System.Console.CmdArgs System.Console.CmdArgs.Annotate
    System.Console.CmdArgs.Default System.Console.CmdArgs.Explicit
    System.Console.CmdArgs.GetOpt System.Console.CmdArgs.Implicit
    System.Console.CmdArgs.Text System.Console.CmdArgs.Helper
    System.Console.CmdArgs.Verbosity System.Console.CmdArgs.Quote
hidden-modules: Data.Generics.Any Data.Generics.Any.Prelude
                System.Console.CmdArgs.Explicit.Complete
                System.Console.CmdArgs.Explicit.ExpandArgsAt
                System.Console.CmdArgs.Explicit.Help
                System.Console.CmdArgs.Explicit.Process
                System.Console.CmdArgs.Explicit.SplitJoin
                System.Console.CmdArgs.Explicit.Type
                System.Console.CmdArgs.Implicit.Ann
                System.Console.CmdArgs.Implicit.Global
                System.Console.CmdArgs.Implicit.Local
                System.Console.CmdArgs.Implicit.Reader
                System.Console.CmdArgs.Implicit.Reform
                System.Console.CmdArgs.Implicit.Type
                System.Console.CmdArgs.Implicit.UI
abi: a8c2ec80b9732abf54ea8157d0a73382
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/cmdargs-0.10.17
library-dirs: /usr/lib/ghc-8.0.2/site-local/cmdargs-0.10.17
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/cmdargs-0.10.17
hs-libraries: HScmdargs-0.10.17-gTr0lzwrHbBcQQ47pfTGo
depends:
    base-4.9.1.0 filepath-1.4.1.1 process-1.4.3.0
    template-haskell-2.11.1.0 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cmdargs/html/cmdargs.haddock
haddock-html: /usr/share/doc/haskell-cmdargs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmdargs-0.10.17-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cmdargs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmdargs
version: 0.10.17
id: cmdargs-0.10.17-GpLpQKwN3eT2vKDqH6rIIr
key: cmdargs-0.10.17-GpLpQKwN3eT2vKDqH6rIIr
license: BSD3
copyright: Neil Mitchell 2009-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/cmdargs#readme
synopsis: Command line argument processing
description:
    This library provides an easy way to define command line parsers. Most users
    will want to use the "System.Console.CmdArgs.Implicit" module, whose
    documentation contains an example.
    .
    * "System.Console.CmdArgs.Explicit" provides a way to write command line
    parsers for both single mode programs (most programs) and multiple
    mode programs (e.g. darcs or cabal). Parsers are defined by constructing
    a data structure.
    .
    * "System.Console.CmdArgs.Implicit" provides a way to concisely define
    command line parsers, up to three times shorter than getopt. These parsers
    are translated into the Explicit data type.
    .
    * "System.Console.CmdArgs.GetOpt" provides a wrapper allowing compatiblity
    with existing getopt parsers, mapping to the Explicit data type.
    .
    For a general reference on what command line flags are commonly used,
    see <http://www.faqs.org/docs/artu/ch10s05.html>.
category: Console
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    System.Console.CmdArgs System.Console.CmdArgs.Annotate
    System.Console.CmdArgs.Default System.Console.CmdArgs.Explicit
    System.Console.CmdArgs.GetOpt System.Console.CmdArgs.Helper
    System.Console.CmdArgs.Implicit System.Console.CmdArgs.Quote
    System.Console.CmdArgs.Text System.Console.CmdArgs.Verbosity
hidden-modules: Data.Generics.Any Data.Generics.Any.Prelude
                System.Console.CmdArgs.Explicit.Complete
                System.Console.CmdArgs.Explicit.ExpandArgsAt
                System.Console.CmdArgs.Explicit.Help
                System.Console.CmdArgs.Explicit.Process
                System.Console.CmdArgs.Explicit.SplitJoin
                System.Console.CmdArgs.Explicit.Type
                System.Console.CmdArgs.Implicit.Ann
                System.Console.CmdArgs.Implicit.Global
                System.Console.CmdArgs.Implicit.Local
                System.Console.CmdArgs.Implicit.Reader
                System.Console.CmdArgs.Implicit.Reform
                System.Console.CmdArgs.Implicit.Type
                System.Console.CmdArgs.Implicit.UI
abi: 814e04fd0adf5c6a510bafac7c16e25e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cmdargs-0.10.17
library-dirs: /usr/lib/ghc-8.2.1/site-local/cmdargs-0.10.17
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/cmdargs-0.10.17
hs-libraries: HScmdargs-0.10.17-GpLpQKwN3eT2vKDqH6rIIr
depends:
    base-4.10.0.0 filepath-1.4.1.2 transformers-0.5.2.0 process-1.6.1.0
    template-haskell-2.12.0.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
haddock-interfaces: /usr/share/doc/haskell-cmdargs/html/cmdargs.haddock
haddock-html: /usr/share/doc/haskell-cmdargs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
